//
// MixW custom callbook sample DLL
//
// by UU9JDR, 2001
//

#include "stdafx.h"

BOOL APIENTRY DllMain( HANDLE hModule, 
                       DWORD  ul_reason_for_call, 
                       LPVOID lpReserved
					 )
{
    switch (ul_reason_for_call)
	{
		case DLL_PROCESS_ATTACH:
		case DLL_THREAD_ATTACH:
		case DLL_THREAD_DETACH:
		case DLL_PROCESS_DETACH:
			break;
    }

    return TRUE;
}

//
// Function LookupCall is called to find a record for the specified callsign
//
// Parameters:
//		sPath	- database path (pathname) entered in Callbook Settings dialog
//		sCall	- callsign to look for
//		sBuffer - memory buffer that MixW gives to copy the record to
//		iBufLen - length of this buffer (10000 bytes)
//

// Return values

#define MCB_FOUND           0		// Callsign is found, record is copied
#define MCB_NOT_FOUND	    1		// Callsign is not found
#define MCB_NO_DATABASE     2		// Bad path or database does not exist
#define MCB_DATABASE_ERROR  3		// Other database error

// Each returned record should consist of 0 or more fields,
// A field constcts of 
//		#1				1 byte
//		field code		1 byte
//		data			0 or more bytes of ASCII string

_declspec(dllexport) int LookupCall(const char* sPath, const char* sCall,
									char* sBuffer, int iBufLen)
{
	// Check the path (open the databese, etc.)
	if ( strlen(sPath) == 0 ) 
		return MCB_NO_DATABASE;  // Should enter the path

	// Look up the callsign
	if ( strcmp(sCall, "UU9JDR") )  
		return MCB_NOT_FOUND;  // Only one callsign - megalomania...

	const char* record = 

		// Personal info
		"\x1\x02"	"UU9JDR"			// Callsign

		"\x1\x03"	"Denis"				// Name
		"\x1\x04"	"Nechitailov"		// Last name
		"\x1\x05"	"N."				// Middle name
		"\x1\x06"	""					// Suffix ("Jr.", etc.)
		"\x1\x07"	"19760413"			// Day of birth, YYYYMMDD

		// Address
		"\x1\x08"	"Gromov 64/84"		// Street
		"\x1\x09"	"Sevastopol"		// City
		"\x1\x0A"	"99002"				// ZIP code
		"\x1\x0B"	""					// State
		"\x1\x0C"	""					// County
		"\x1\x0D"	"44.525"			// Latitude, deg.
		"\x1\x0E"	"33.475"			// Longitude, deg.
		"\x1\x0F"	"KN64RO"			// Grid square

		"\x1\x10"	"Denis Nechitailov, Gromov st. 64/84, Sevastopol" // Name & address
						// if the database does not have separate fields		

		"\x1\x11"	"uu9jdr@qsl.net"		// Email address
		"\x1\x12"	"www.qsl.net/uu9jdr/"	// WWW homepage
		"\x1\x13"	""			// Phone/FAX number
		
		"\x1\x14"	""			// QSL manager

		"\x1\xFF"	"Prev.call: UT5JDR; Hobby: Likes beer"	// Comment, includes other info

		// Please suggest new fields!

		"\0";  // End of record

	int length = strlen(record);

	// Check the length of record
	if ( length+1 >= iBufLen )  // notice closing '\0'
		return MCB_DATABASE_ERROR;

	memcpy( sBuffer, record, length+1); // notice closing '\0'

	return MCB_FOUND; // Ok
}

